/*
 * @(#) $Header$
 * $Source$
 */

#ifndef _H_SB
#define _H_SB

#include <sys/soundcard.h>

/* PCM and ADPCM (compression) definitions */
#define PCM_8			0x01
#define ADPCM_2			0x02
#define ADPCM_3			0x03
#define ADPCM_4			0x04

/* Device Names */
#define AWDSP	"/dev/awdsp0"
#define AWFM    "/dev/awfm0"
#define AWMIX   "/dev/awmix0"
#define AWMIDI  "/dev/awmidi0"

/* FM IOCTLS */
#define FM_IOCTL_RESET        0x20
#define FM_IOCTL_PLAY_NOTE    0x21
#define FM_IOCTL_SET_VOICE    0x22
#define FM_IOCTL_SET_PARAMS   0x23
#define FM_IOCTL_SET_MODE     0x24
#define FM_IOCTL_SET_OPL      0x25

#define OPL2		0
#define OPL3		1

/* MIXER IOCTLS */
#define MIXER_IOCTL_SET_LEVELS	0x30
#define MIXER_IOCTL_SET_PARAMS	0x31
#define MIXER_IOCTL_READ_LEVELS	0x32
#define MIXER_IOCTL_READ_PARAMS	0x33
#define MIXER_IOCTL_RESET	0x34

/*
 * Data structure composing an FM "note" or sound event.
 */
struct aw_fm_voice
{
  unsigned char op;               	/* Operator cell (0 or 1) */
  unsigned char voice;                  /* FM voice (0 to 17) */

  unsigned char am;                     /* Amplitude modulation */
  unsigned char vibrato;                /* Vibrato effect */
  unsigned char do_sustain;             /* Sustain phase */
  unsigned char kbd_scale;              /* Keyboard scaling */
  unsigned char harmonic;               /* 4 bits: Harmonic or multiplier */
  unsigned char scale_level;            /* 2 bits: Decrease output  freq rises*/
  unsigned char volume;                 /* 6 bits: Volume */

  unsigned char attack;                 /* 4 bits: Attack rate */
  unsigned char decay;                  /* 4 bits: Decay rate */
  unsigned char sustain;                /* 4 bits: Sustain level  */
  unsigned char release;                /* 4 bits: Release rate */

  unsigned char feedback;               /* 3 bits: Feedback for op0 */
  unsigned char connection;             /* 0 for serial, 1 for parallel*/
  unsigned char left;                   /* Stereo Right */
  unsigned char right;                  /* Stereo Right */
  unsigned char waveform;               /* 3 bits: Waveform shape */
};

struct aw_fm_note
{
  unsigned char voice;			/* 0-17 voice channel */
  unsigned char octave;                 /* 3 bits: What octave to play*/
  unsigned int fnum;                    /* 10 bits: Frequency "number" */
  unsigned char key_on;                 /* Set for active, Clear for silent */
};

/*
 * FM parameters that apply globally to all voices, and thus are not "notes"
 */
struct aw_fm_params
{
  unsigned char am_depth;                /* Amplitude Modulation depth (1=hi) */
  unsigned char vib_depth;               /* Vibrato depth (1=hi) */
  unsigned char kbd_split;               /* Keyboard split */
  unsigned char rhythm;                  /* Percossion mode select */

  /* Percossion instruments */
  unsigned char bass;
  unsigned char snare;
  unsigned char tomtom;
  unsigned char cymbal;
  unsigned char hihat;
};

/*
 * MIXER IOCTLs and STRUCTS 
 */

struct aw_mixer_params
{
 unsigned char record_source;
 unsigned char filter_input;
 unsigned char hifreq_input;
 unsigned char filter_output;
 unsigned char stereo_output;
};

struct stereo_vol
{
  unsigned char l;	/*left volume*/
  unsigned char r; 	/*right volume*/
};

struct aw_mixer_levels
{
  struct stereo_vol master;	/*Master volume*/
  struct stereo_vol voc;	/*DSP voice volume*/
  struct stereo_vol fm;		/*FM volume*/
  struct stereo_vol line;	/*Line in volume*/
  struct stereo_vol cd;		/*CD volume*/
  unsigned char mic;		/*MIC volume*/
};
#define SRC_CD		2
#define SRC_MIC		0
#define SRC_LINE	6
#endif /* _H_SB */

